##############################################################################
#
# Copyright (c) 2010 Nexedi SA and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is free software: you can Use, Study, Modify and Redistribute
# it under the terms of the GNU General Public License version 3, or (at your
# option) any later version, as published by the Free Software Foundation.
#
# You can also Link and Combine this program with other software covered by
# the terms of any of the Free Software licenses or any of the Open Source
# Initiative approved licenses and Convey the resulting work. Corresponding
# source of such a combination shall include the source code for all other
# software used.
#
# This program is distributed WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
# See COPYING file for full licensing terms.
# See https://www.nexedi.com/licensing for rationale and options.
#
##############################################################################
import os

from slapos.recipe.librecipe import GenericBaseRecipe

class Recipe(GenericBaseRecipe):

  def install(self):
    logrotate_d = self.options['logrotate-entries']
    logrotate_conf_file = self.options['conf']

    logrotate_conf = [
      'compresscmd %s' % self.options['gzip-binary'],
      'compressoptions -9',
      'uncompresscmd %s' % self.options['gunzip-binary'],
      'include %s' % logrotate_d,
    ]

    logrotate_conf_file = self.createFile(logrotate_conf_file,
        '\n'.join(logrotate_conf))

    state_file = self.options['state-file']

    logrotate = self.createWrapper(
      self.options['wrapper'],
      (self.options['logrotate-binary'],
        '-s', state_file, logrotate_conf_file),
    )

    return [logrotate, logrotate_conf_file]

class Part(GenericBaseRecipe):

  def install(self):

    logrotate_d = self.options['logrotate-entries']

    conf = [
      'daily',
      'dateext',
      'rotate 3650',
      'compress',
      'delaycompress',
      'notifempty',
      'sharedscripts',
      'create',
      'olddir %s' % self.options['backup'],
    ]

    if 'post' in self.options:
      conf.append("postrotate\n%s\nendscript" % self.options['post'])
    if 'pre' in self.options:
      conf.append("prerotate\n%s\nendscript" % self.options['pre'])

    log = self.options['log']

    part_path = self.createFile(os.path.join(logrotate_d, self.options['name']),
                    "%(logfiles)s {\n%(conf)s\n}\n" % {
                      'logfiles': log,
                      'conf': '\n'.join(conf),
                    }
                   )

    return [part_path]
