##############################################################################
#
# Copyright (c) 2010 Nexedi SA and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is free software: you can Use, Study, Modify and Redistribute
# it under the terms of the GNU General Public License version 3, or (at your
# option) any later version, as published by the Free Software Foundation.
#
# You can also Link and Combine this program with other software covered by
# the terms of any of the Free Software licenses or any of the Open Source
# Initiative approved licenses and Convey the resulting work. Corresponding
# source of such a combination shall include the source code for all other
# software used.
#
# This program is distributed WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
# See COPYING file for full licensing terms.
# See https://www.nexedi.com/licensing for rationale and options.
#
##############################################################################
import zc.buildout

from slapos.recipe.librecipe import GenericSlapRecipe

class Recipe(GenericSlapRecipe):

  def _options(self, options):

    self.useparts = True

    if 'url' in options:
      self.useparts = False
      self.url = options['url']
    else:
      self.urlparts = {}

      if 'scheme' not in options:
        raise zc.buildout.UserError("No scheme specified.")
      else:
        self.urlparts.update(scheme=options['scheme'])
      if 'host' not in options:
        raise zc.buildout.UserError("No host specified.")
      else:
        self.urlparts.update(host=options['host'])

  def _install(self):

    if self.useparts:
      for option in ['path', 'params', 'query', 'fragment', 'port']:
        if option in self.options:
          self.urlparts[option] = self.options[option]

      if 'username' in self.options:
        self.urlparts.update(auth=(self.options['username'],))
        if 'password' in self.options:
          self.urlparts.update(auth=(self.options['username'],
                                     self.options['password']))

      self.setConnectionUrl(**self.urlparts)
    else:
      self.setConnectionDict(dict(url=self.url))

    return []
