# vim: set et sts=2:
##############################################################################
#
# Copyright (c) 2013 Nexedi SA and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is free software: you can Use, Study, Modify and Redistribute
# it under the terms of the GNU General Public License version 3, or (at your
# option) any later version, as published by the Free Software Foundation.
#
# You can also Link and Combine this program with other software covered by
# the terms of any of the Free Software licenses or any of the Open Source
# Initiative approved licenses and Convey the resulting work. Corresponding
# source of such a combination shall include the source code for all other
# software used.
#
# This program is distributed WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
# See COPYING file for full licensing terms.
# See https://www.nexedi.com/licensing for rationale and options.
#
##############################################################################

import errno

class Recipe(object):
  """Read the first line of a file.

  As the result has to be provided as an options, it is mandatory that the
  buildout profile fills the file content (if needed) before trying to read it.

    Options:
    - storage-path: file to read

    Result set in options:
    - readline: first line of the file
  """

  def __init__(self, buildout, name, options):
    storage_path = options['storage-path']
    try:
      with open(storage_path) as f:
        readline = f.readline()
    except IOError, e:
      if e.errno != errno.ENOENT:
        raise
      readline = None

    self.readline = readline
    options['readline'] = readline

  def install(self):
    if self.readline is None:
      raise ValueError('Unable to read the file content.')
    return ()

  def update(self):
    return ()
