##############################################################################
#
# Copyright (c) 2019 Nexedi SA and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is free software: you can Use, Study, Modify and Redistribute
# it under the terms of the GNU General Public License version 3, or (at your
# option) any later version, as published by the Free Software Foundation.
#
# You can also Link and Combine this program with other software covered by
# the terms of any of the Free Software licenses or any of the Open Source
# Initiative approved licenses and Convey the resulting work. Corresponding
# source of such a combination shall include the source code for all other
# software used.
#
# This program is distributed WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
# See COPYING file for full licensing terms.
# See https://www.nexedi.com/licensing for rationale and options.
#
##############################################################################


import httplib
import json
import os
import requests

from slapos.testing.testcase import makeModuleSetUpAndTestCaseClass

setUpModule, InstanceTestCase = makeModuleSetUpAndTestCaseClass(
    os.path.abspath(
        os.path.join(os.path.dirname(__file__), '..', 'software.cfg')))


class TestBackupServer(InstanceTestCase):

  def test(self):
    parameter_dict = self.computer_partition.getConnectionParameterDict()

    # Check that there is a RSS feed
    self.assertTrue('rss' in parameter_dict)
    self.assertTrue(parameter_dict['rss'].startswith(
      'https://[%s]:9443/' % (self._ipv6_address, )
    ))

    result = requests.get(
      parameter_dict['rss'], verify=False, allow_redirects=False)

    # XXX crontab not triggered yet
    self.assertEqual(
      [httplib.NOT_FOUND, False],
      [result.status_code, result.is_redirect]
    )

    # Check monitor
    self.assertTrue('monitor-base-url' in parameter_dict)
    self.assertTrue('monitor-setup-url' in parameter_dict)

    result = requests.get(
      parameter_dict['monitor-base-url'], verify=False, allow_redirects=False)
    self.assertEqual(
      [httplib.UNAUTHORIZED, False],
      [result.status_code, result.is_redirect]
    )
