##############################################################################
#
# Copyright (c) 2019 Nexedi SA and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is free software: you can Use, Study, Modify and Redistribute
# it under the terms of the GNU General Public License version 3, or (at your
# option) any later version, as published by the Free Software Foundation.
#
# You can also Link and Combine this program with other software covered by
# the terms of any of the Free Software licenses or any of the Open Source
# Initiative approved licenses and Convey the resulting work. Corresponding
# source of such a combination shall include the source code for all other
# software used.
#
# This program is distributed WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
# See COPYING file for full licensing terms.
# See https://www.nexedi.com/licensing for rationale and options.
#
##############################################################################

import os
import requests

from slapos.testing.testcase import makeModuleSetUpAndTestCaseClass

setUpModule, SlapOSInstanceTestCase = makeModuleSetUpAndTestCaseClass(
    os.path.abspath(
        os.path.join(os.path.dirname(__file__), '..', 'software.cfg')))


class HelloWorldTestCase(SlapOSInstanceTestCase):
  # to be defined by subclasses
  name = None
  kind = None

  @classmethod
  def getInstanceParameterDict(cls):
    return {"name": cls.name}


class HTTPRequestTestMixin(object):
  """Test that the service url.${kind} responds Hello ${name}
  """
  def test_get(self):
    url = self.computer_partition.getConnectionParameterDict()['url.{}'.format(
        self.kind)]
    response = requests.get(url)
    self.assertEqual(requests.codes['OK'], response.status_code)
    self.assertTrue(
        response.text.startswith("Hello {}".format(self.name)), response.text)


class TestPython(HelloWorldTestCase, HTTPRequestTestMixin):
  name = "Python"
  kind = "python"


class TestRuby(HelloWorldTestCase, HTTPRequestTestMixin):
  name = "Ruby"
  kind = "ruby"


class TestGolang(HelloWorldTestCase, HTTPRequestTestMixin):
  name = "Go"
  kind = "go"
