##############################################################################
#
# Copyright (c) 2019 Nexedi SA and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is free software: you can Use, Study, Modify and Redistribute
# it under the terms of the GNU General Public License version 3, or (at your
# option) any later version, as published by the Free Software Foundation.
#
# You can also Link and Combine this program with other software covered by
# the terms of any of the Free Software licenses or any of the Open Source
# Initiative approved licenses and Convey the resulting work. Corresponding
# source of such a combination shall include the source code for all other
# software used.
#
# This program is distributed WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
# See COPYING file for full licensing terms.
# See https://www.nexedi.com/licensing for rationale and options.
#
##############################################################################


import httplib
import json
import os
import requests

from slapos.testing.testcase import makeModuleSetUpAndTestCaseClass

setUpModule, InstanceTestCase = makeModuleSetUpAndTestCaseClass(
    os.path.abspath(
        os.path.join(os.path.dirname(__file__), '..', 'software.cfg')))


class TestJSTestNode(InstanceTestCase):

  def test(self):
    parameter_dict = self.computer_partition.getConnectionParameterDict()
    self.assertTrue('_' in parameter_dict)
    try:
      connection_dict = json.loads(parameter_dict['_'])
    except Exception as e:
      self.fail("Can't parse json in %s, error %s" % (parameter_dict['_'], e))

    self.assertEqual(
      {
        'nginx': 'http://[%s]:9443/' % (self._ipv6_address, )
      },
      connection_dict
    )

    # jio tests
    result = requests.get(
      '%sjio/test/tests.html' % (connection_dict['nginx'], ), allow_redirects=False)
    self.assertEqual(
      [httplib.OK, False],
      [result.status_code, result.is_redirect]
    )

    # rjs tests
    result = requests.get(
      '%srenderjs/test/' % (connection_dict['nginx'], ), allow_redirects=False)
    self.assertEqual(
      [httplib.OK, False],
      [result.status_code, result.is_redirect]
    )

    # rsvp tests
    result = requests.get(
      '%srsvp/test/index.html' % (connection_dict['nginx'], ), allow_redirects=False)
    self.assertEqual(
      [httplib.OK, False],
      [result.status_code, result.is_redirect]
    )

    # Default access
    result = requests.get(
      'http://[%s]:9443' % (self._ipv6_address, ), allow_redirects=False)
    self.assertEqual(
      [httplib.FORBIDDEN, False],
      [result.status_code, result.is_redirect]
    )
