##############################################################################
# coding: utf-8
#
# Copyright (c) 2020 Nexedi SA and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is free software: you can Use, Study, Modify and Redistribute
# it under the terms of the GNU General Public License version 3, or (at your
# option) any later version, as published by the Free Software Foundation.
#
# You can also Link and Combine this program with other software covered by
# the terms of any of the Free Software licenses or any of the Open Source
# Initiative approved licenses and Convey the resulting work. Corresponding
# source of such a combination shall include the source code for all other
# software used.
#
# This program is distributed WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
# See COPYING file for full licensing terms.
# See https://www.nexedi.com/licensing for rationale and options.
#
##############################################################################

import os
import json
from six.moves.urllib import parse
import requests

from slapos.testing.testcase import makeModuleSetUpAndTestCaseClass

setUpModule, MetabaseTestCase = makeModuleSetUpAndTestCaseClass(
    os.path.abspath(
        os.path.join(os.path.dirname(__file__), '..', 'software.cfg')))


class TestMetabaseSetup(MetabaseTestCase):
  __partition_reference__ = 'S'  # postgresql use a socket in data dir
  # instance can take time, /api/session/properties timeout at the beginning.
  instance_max_retry = 30

  def test_setup(self):
    url = self.computer_partition.getConnectionParameterDict()['url']
    resp = requests.get(parse.urljoin(url, '/setup'), verify=False)
    self.assertTrue(resp.text)

    # get a setup token as described in https://github.com/metabase/metabase/issues/4240#issuecomment-290717451
    properties = requests.get(
        parse.urljoin(url, '/api/session/properties'), verify=False,
        timeout=10).json()

    email = "youlooknicetoday@email.com"
    password = "password123456"

    request_json = {
        'token': properties['setup-token'],
        'prefs': {
            'allow_tracking': 'false',
            'site_name': 'Org'
        },
        'user': {
            'email': email,
            'password': password,
            'first_name': 'Johnny',
            'last_name': 'Appleseed',
            'site_name': 'Org',
        },
        'database': None
    }
    resp = requests.post(
        parse.urljoin(url, '/api/setup'),
        json=request_json,
        verify=False,
        timeout=5)
    self.assertTrue(resp.ok)

    resp = requests.post(
        parse.urljoin(url, '/api/session'),
        verify=False,
        json={
            "username": email,
            "password": "wrong"
        })
    self.assertEqual(requests.codes.bad_request, resp.status_code)

    session = requests.post(
        parse.urljoin(url, '/api/session'),
        verify=False,
        json={
            "username": email,
            "password": password
        }).json()
    self.assertTrue(session.get('id'))
